from django.test import TestCase

from web.models import Appointment
from web.models import Visit
from web.tests.functions import create_study_subject, create_appointment, create_study_subject_with_multiple_screening_numbers
from web.tests.functions import create_visit


class SubjectModelTests(TestCase):
    def test_mark_as_resigned(self):
        subject = create_study_subject()
        visit = create_visit(subject)
        appointment = create_appointment(visit)

        subject.mark_as_resigned()
        appointment_status = Appointment.objects.filter(id=appointment.id)[0].status
        visit_finished = Visit.objects.filter(id=visit.id)[0].is_finished

        self.assertTrue(subject.resigned)
        self.assertTrue(visit_finished)
        self.assertEquals(Appointment.APPOINTMENT_STATUS_CANCELLED, appointment_status)

    def test_sort_matched_screening_first(self):

        def create_result(phrase, subject_id=1):
            phrase = phrase.format(subject_id=subject_id)
            phrase = phrase.split(';')
            for i,r in enumerate(phrase):
                letter, num = phrase[i].strip().split('-')
                phrase[i] = (letter, int(num))
            return phrase

        subject = create_study_subject_with_multiple_screening_numbers(subject_id=1)
        self.assertEqual(subject.sort_matched_screening_first('L'), create_result('L-00{subject_id}; E-00{subject_id}', subject_id=1))
        self.assertEqual(subject.sort_matched_screening_first('L-00'), create_result('L-00{subject_id}; E-00{subject_id}', subject_id=1))
        self.assertEqual(subject.sort_matched_screening_first('E'), create_result('E-00{subject_id}; L-00{subject_id}', subject_id=1))
        self.assertEqual(subject.sort_matched_screening_first('-'), create_result('E-00{subject_id}; L-00{subject_id}', subject_id=1))
        self.assertEqual(subject.sort_matched_screening_first(''), create_result('E-00{subject_id}; L-00{subject_id}', subject_id=1))
        self.assertEqual(subject.sort_matched_screening_first('001'), create_result('E-00{subject_id}; L-00{subject_id}', subject_id=1))
        self.assertEqual(subject.sort_matched_screening_first('00'), create_result('E-00{subject_id}; L-00{subject_id}', subject_id=1))
        self.assertEqual(subject.sort_matched_screening_first('potato'), create_result('E-00{subject_id}; L-00{subject_id}', subject_id=1))
        